"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PlaceManagerEvent = exports.PlaceManager = exports.GimbalDebugger = exports.Gimbal = exports.BatteryLevel = void 0;
var _reactNative = require("react-native");
const LINKING_ERROR = `The package 'rtn-gimbal-sdk' doesn't seem to be linked. Make sure: \n\n` + _reactNative.Platform.select({
  ios: "- You have run 'pod install'\n",
  default: ''
}) + '- You rebuilt the app after installing the package\n' + '- You are not using Expo Go\n';

// @ts-expect-error
const isTurboModuleEnabled = global.__turboModuleProxy != null;
const GimbalModule = isTurboModuleEnabled ? require('./NativeGimbal').default : _reactNative.NativeModules.RtnGimbal;
const Gimbal = GimbalModule ? GimbalModule : new Proxy({}, {
  get() {
    throw new Error(LINKING_ERROR);
  }
});
exports.Gimbal = Gimbal;
const PlaceManagerModule = isTurboModuleEnabled ? require('./NativePlaceManager').default : _reactNative.NativeModules.RtnGimbalPlaceManager;
const PlaceManager = PlaceManagerModule ? PlaceManagerModule : new Proxy({}, {
  get() {
    throw new Error(LINKING_ERROR);
  }
});
exports.PlaceManager = PlaceManager;
const {
  BATTERY_LEVEL_LOW,
  BATTERY_LEVEL_MEDIUM_LOW,
  BATTERY_LEVEL_MEDIUM_HIGH,
  BATTERY_LEVEL_HIGH,
  EVENT_VISIT_START,
  EVENT_VISIT_START_WITH_DELAY,
  EVENT_VISIT_END,
  EVENT_PLACE_BEACON_SIGHTING,
  EVENT_LOCATION_DETECTED
} = PlaceManager.getConstants();
const BatteryLevel = {
  LOW: BATTERY_LEVEL_LOW,
  MEDIUM_LOW: BATTERY_LEVEL_MEDIUM_LOW,
  MEDIUM_HIGH: BATTERY_LEVEL_MEDIUM_HIGH,
  HIGH: BATTERY_LEVEL_HIGH
};
exports.BatteryLevel = BatteryLevel;
const PlaceManagerEvent = {
  VISIT_START: EVENT_VISIT_START,
  VISIT_START_WITH_DELAY: EVENT_VISIT_START_WITH_DELAY,
  VISIT_END: EVENT_VISIT_END,
  BEACON_SIGHTING: EVENT_PLACE_BEACON_SIGHTING,
  LOCATION_DETECTED: EVENT_LOCATION_DETECTED
};
exports.PlaceManagerEvent = PlaceManagerEvent;
const GimbalDebuggerModule = isTurboModuleEnabled ? require('./NativeGimbalDebugger').default : _reactNative.NativeModules.RtnGimbalDebugger;
const GimbalDebugger = GimbalDebuggerModule ? GimbalDebuggerModule : new Proxy({}, {
  get() {
    throw new Error(LINKING_ERROR);
  }
});
exports.GimbalDebugger = GimbalDebugger;
//# sourceMappingURL=index.js.map